==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Aproximarea planului...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Aproximaţi un plan</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation type="unfinished">Approximate B-spline surface...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation type="unfinished">Approximate a B-spline surface</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation type="unfinished">Approximate B-Spline surface...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Aproximarea suprafeței...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Aproximarea unei suprafețe B-Spline</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation type="unfinished">Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation type="unfinished">Poisson surface reconstruction</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation type="unfinished">Structured point clouds</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation type="unfinished">Triangulation of structured point clouds</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation type="unfinished">Fit B-Spline surface</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation type="unfinished">Fit B-spline surface</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation type="unfinished">u-Direction</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation type="unfinished">Degree</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation type="unfinished">Control points</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation type="unfinished">v-Direction</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>Setari</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation type="unfinished">Iterations</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation type="unfinished">Size factor</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Netezire</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation type="unfinished">Total Weight</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation type="unfinished">Length of gradient</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation type="unfinished">Bending energy</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation type="unfinished">Curvature variation</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation type="unfinished">User-defined u/v directions</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Selecţie greşită</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation type="unfinished">Please select a single placement object to get local orientation.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Eroare de intrare</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation type="unfinished">Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation type="unfinished">Parameters</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation type="unfinished">Octree depth</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation type="unfinished">Solver divide</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation type="unfinished">Samples per node</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Eroare de intrare</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Selecţie greşită</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation type="unfinished">Please select a single point cloud.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation type="unfinished">View triangulation failed</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Aproximarea planului...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Aproximaţi un plan</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>Aproximează o suprafață de B-spline...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>Aproximează o suprafaţă de B-spline</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Aproximează o suprafață de B-spline...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Aproximarea suprafeței...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Aproximarea unei suprafețe B-Spline</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Reconstrucţia suprafaţă Poisson</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Nor de puncte structurate</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Triangulaţie structurii norului de puncte</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Adaptați o suprafata de B-Spline</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>Adaptați o suprafata de B-Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>direcția U</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Grad</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Puncte de control</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>direcția V</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>Setari</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Iteraţii</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Factor de dimensiune</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Netezire</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Greutatea totală</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Lungimea degradeului</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Energiea de îndoire</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Variaţie de curbură</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Direcții u/v personalizate</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Selecţie greşită</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Vă rugăm să selectaţi un obiect unic de plasare pentru a obţine orientarea locală.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Eroare de intrare</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Parametrii</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Adâncimea unui arbore [octree] în care fiecare nod are exact 8 copii</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Diviziuni ale rezolvitorului</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Eșantioane pe nod</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Eroare de intrare</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Selecţie greşită</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Va rugam selectati un singur nor de puncte.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Eroarea la vederea de triangulație</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Inginerie Inversă</translation>
    </message>
  </context>
</TS>
